import { Component, Input } from '@angular/core';
import { CommonModule, DatePipe, DecimalPipe } from '@angular/common';

@Component({
  selector: 'app-event-table',
  standalone: true,
  imports: [CommonModule, DatePipe, DecimalPipe],
  templateUrl: './event-table.component.html',
  styleUrls: ['./event-table.component.scss']
})
export class EventTableComponent {
  @Input() events: any[] = [];
  @Input() currentPage = 1;
  @Input() totalPages = 1;
  
  // 添加缺失的方法
  exportCSV() {
    // 实现CSV导出逻辑
    const headers = ['时间', '事件类型', '设备', '振动值(g)', '持续时间'];
    const rows = this.events.map(event => [
      event.eventTime,
      event.eventType,
      event.deviceId,
      event.vibrationValue,
      event.duration
    ]);
    
    const csvContent = [headers, ...rows].map(row => 
      row.map(field => `"${field}"`).join(',')
    ).join('\n');
    
    this.downloadFile(csvContent, '振动事件.csv');
  }

  private downloadFile(content: string, filename: string) {
    const blob = new Blob([content], { type: 'text/csv;charset=utf-8;' });
    const link = document.createElement('a');
    const url = URL.createObjectURL(blob);
    
    link.setAttribute('href', url);
    link.setAttribute('download', filename);
    link.style.visibility = 'hidden';
    
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
  }

  showDetails(event: any) {
    console.log('事件详情:', event);
    alert(`事件详情:
时间: ${event.eventTime}
类型: ${event.eventType}
设备: ${event.deviceId}
振动值: ${event.vibrationValue}g
持续时间: ${event.duration}`);
  }
}